IDataSource class abstract

Implementers

Constructors

IDataSource()

Properties

autoexecute ↔ bool?
getter/setter pair
body ↔ String?
getter/setter pair
bodyObservable → StringObservable?
no setter
busy → bool
no setter
custombody → bool
no setter
data → Data?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setter
initialized ↔ bool
getter/setter pair
parent → Model?
no setter
root ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear({int? start, int? end}) → Future<bool>
delete(int? index, {bool notifyListeners = true}) → Future<bool>
dispose() → dynamic
insert(String? jsonOrXml, int? index, {bool notifyListeners = true}) → Future<bool>
move(dynamic from, dynamic to, {bool notifyListeners = true}) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify() → dynamic
onSuccess(Data data, {int? code, String? message, Observable? onSuccessOverride}) → Future<bool>
register(IDataSourceListener listener) → dynamic
remove(IDataSourceListener listener) → dynamic
start({bool refresh = false, String? key}) → Future<bool>
stop() → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited