Barcode class

Constructors

Barcode()

Properties

barcode ↔ String?
getter/setter pair
display ↔ String?
getter/setter pair
format ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parameters ↔ Map<String, String?>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String?
getter/setter pair
type ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited