BarcodeDetector class

Implemented types

Constructors

BarcodeDetector()
factory

Properties

count ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect(dynamic detectable, List<BarcodeFormats>? formats, bool? tryharder, bool? invert) → Future<Payload?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited