DetectableImage class
Constructors
- DetectableImage(dynamic image)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCamera(
CameraImage image, CameraDescription camera) → Future< DetectableImage> -
fromFile(
XFile file) → Future< DetectableImage> -
fromRgba(
List< int> bytes, int width, int height) → Future<DetectableImage>