FileBase class

Implemented types
Implementers

Constructors

FileBase(dynamic file, String url, String name, String? mimeType, int size)

Properties

bytes ↔ Uint8List?
getter/setter pairoverride-getter
file → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
mimeType → String?
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
final
uri → String?
no setteroverride
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read({int? start, int? end}) → Future<Uint8List?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited