File class abstract

Implementers

Constructors

File(dynamic file, String url, String name, String mimeType, int size)
factory

Properties

bytes → Uint8List?
no setter
hashCode → int
The hash code for this object.
no setterinherited
mimeType → String?
no setter
name → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
no setter
uri → String?
no setter
url → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read({int? start, int? end}) → Future<Uint8List?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited