Gps class

Constructors

Gps()
factory

Properties

busy ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
last ↔ Payload?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners(Payload? data) → Future<bool>
registerListener(IGpsListener listener) → dynamic
removeListener(IGpsListener listener) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited