dispose method
disposes of the model releasing resources and removing bindings
Implementation
@override
void dispose() {
System().gps.removeListener(this);
super.dispose();
}
disposes of the model releasing resources and removing bindings
@override
void dispose() {
System().gps.removeListener(this);
super.dispose();
}