Http class

Constructors

Http()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decodeHeaders(Response response) → void
delete(String url, {Map<String, String>? headers, int? timeout = 60}) → Future<HttpResponse>
encodeHeaders(Map<String, String>? headers) → Map<String, String>
encodeUri(String url, {bool refresh = false}) → Uri?
get(String url, {Map<String, String>? headers, int? timeout = 60, bool refresh = false}) → Future<HttpResponse>
patch(String url, String? body, {Map<String, String>? headers, int? timeout = 60}) → Future<HttpResponse>
post(String url, String body, {Map<String, String>? headers, int? timeout = 60}) → Future<HttpResponse>
put(String url, String body, {Map<String, String>? headers, int? timeout = 60}) → Future<HttpResponse>