HttpResponse class

Constructors

HttpResponse(String url, {dynamic body, dynamic bytes, String? contentType, int? statusCode, String? statusMessage})
HttpResponse.factory(String url, Response response)
factory

Properties

body → dynamic
final
bytes → dynamic
final
contentType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
ok → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int?
final
statusMessage → String?
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited