IMqtt class abstract

Implementers

Constructors

IMqtt()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() Future<bool>
disconnect() Future<bool>
dispose() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(String topic, String msg) Future<bool>
subscribe(String topic) Future<bool>
toString() String
A string representation of this object.
inherited
unsubscribe(String topic) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(String url, IMqttListener listener, {String? username, String? password}) IMqtt?