Reader class

Constructors

Reader()
factory

Properties

a ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
polling ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stop ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners(Payload data) → dynamic
read() → dynamic
readNFCTag(NFCTag tag) → Future<String?>
registerListener(INfcListener listener) → dynamic
removeListener(INfcListener listener) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited