Socket class

Constructors

Socket(String? url, ISocketListener listener)

Properties

connected ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastMessage ↔ String?
getter/setter pair
listener → ISocketListener
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ Uri?
getter/setter pair
url → String?
no setter

Methods

connect({bool forceReconnect = false}) → Future<bool>
disconnect() → Future<bool>
dispose() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reconnect(String? url) → Future
send(dynamic message) → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited