Reader class

Constructors

Reader()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel ↔ MethodChannel?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanChannel ↔ EventChannel?
getter/setter pair

Methods

getPayload(Map? result) → Payload?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners(Payload? data) → dynamic
registerListener(IZebraListener listener) → dynamic
removeListener(IZebraListener listener) → dynamic
startScan() → dynamic
stopScan() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited