CallExpression class

Inheritance

Constructors

CallExpression(Expression? callee, List<Expression?>? arguments)

Properties

arguments → List<Expression?>?
final
callee → Expression?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toTokenString() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited