EventHandler class
EventHandler performs the executions of events and contains the functions for each event Type
Some events are handled internally while others are broadcasted and handled
within the appropriate widget(s) usually with the prefix 'on', example: onClose
Constructors
- EventHandler(Model model)
Properties
Methods
-
evaluate(
String expression, Map< String?, dynamic> variables) → Future<String?> -
override
-
execute(
Observable? observable) → Future< bool> -
executeEvent(
String event, {Map< String?, dynamic> ? variables}) → Future -
executeExpression(
String? expression, Map< String, dynamic> variables) → Future<bool> -
initialize(
) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- nonQuotedSemiColons → RegExp
-
final
- thisDot → RegExp
-
final
Static Methods
-
formatExpression(
String expression) → String -
getConditionals(
Expression? parsed) → List< String> -
getVariables(
List< Binding> ? bindings, Model local, Model remote, {List<String> localAliasNames = const ['this', 'source', 'src'], List<String> remoteAliasNames = const ['target', 'trg']}) → Map<String, dynamic>
Constants
- evaluator → const ExpressionEvaluator