Data class

Constructors

Data({String? key, String? value, int? expires})

Properties

expires → int?
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
no setter

Methods

delete() → Future<bool>
insert() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update() → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

tableName ↔ String
getter/setter pair

Static Methods

deleteAll() → Future<bool>
find(String key) → Future<Data?>