Stash class

Constructors

Stash(String key, Map<String, dynamic> map, {Scope? scope})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
final
map → Map<String, dynamic>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → Scope?
final

Methods

delete() → Future<bool>
insert() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
upsert() → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

tableName ↔ String
getter/setter pair

Static Methods

get(String key, {Scope? scope}) → Future<Stash>
getStash(String domain) → Future<Stash>
getStashData(String domain) → Future<Data>