User class

Constructors

User({String? key, String? username, String? password, int? rights, String? language, Map<String, dynamic>? map})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
no setter
language → String?
no setter
password → String?
no setter
rights → int?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String?
no setter

Methods

delete() → Future<bool>
insert() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update() → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

tableName ↔ String
getter/setter pair

Static Methods

deleteAll() → Future<bool>
find(String key) → Future<User?>
query({String? where, String? orderby}) → Future<List<User>>