Janitor class

The janitor service is used to cleanup old files

Constructors

Janitor()
factory

Properties

busy ↔ bool
getter/setter pair
formRetention ↔ int
getter/setter pair
frequency ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
postRetention ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timer ↔ Timer?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → Future<bool>
stop() → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited