Binding class

Constructors

Binding({String? scope, required String signature, required String source, required String property, bool? isEval, DotNotation? dotnotation, int? offset})

Properties

dotnotation → DotNotation?
final
hashCode → int
The hash code for this object.
no setterinherited
isEval → bool?
final
key → String?
no setter
offset → int?
final
property → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String?
///////////////////////////////////////////
final
signature → String
final
source → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
translate(dynamic value) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

reg → RegExp
final

Static Methods

applyMap(String? xml, Map? map, {String? source, bool caseSensitive = true, String? prefix, bool encode = false}) → String?
fromString(String? binding, {Scope? bindingscope}) → Binding?
getBindingKeys(String s) → List<String>?
getBindings(String? s, {Scope? scope}) → List<Binding>?
getBindingStrings(String s) → List<String?>?
hasBindings(String? s) → bool
toKey(String? source, [String? property]) → String?