Scope class

Constructors

Scope({Scope? parent, String? id})

Properties

children ↔ List<Scope>?
getter/setter pair
datasources ↔ LinkedHashMap<String, IDataSource>
getter/setter pair
files → Map<String, File>
final
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
models ↔ LinkedHashMap<String, Model>
getter/setter pair
observables ↔ HashMap<String?, Observable>
getter/setter pair
parent ↔ Scope?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unresolved ↔ HashMap<String?, List<Observable>>
getter/setter pair

Methods

addChild(Scope child) → void
bind(Observable target) → bool
dispose() → void
findModel(String id) → Model?
getDataSource(String? id) → IDataSource?
getObservable(Binding binding, {Observable? requestor}) → Observable?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(Observable observable) → bool
registerDataSource(IDataSource source) → void
registerModel(Model model) → void
removeChild(Scope child) → void
removeDataSource(IDataSource source) → void
replaceFileReferences(String? body) → Future<String?>
setObservable(String? key, dynamic value) → void
toString() → String
A string representation of this object.
inherited
unregisterModel(Model model) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

findNamedScope(String? id) → Scope?
of(Model? model) → Scope?