ScopeManager class

Constructors

ScopeManager()

Properties

directory → HashMap<String, List<Scope>>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unresolved ↔ HashMap<String?, List<Observable>>?
getter/setter pair

Methods

add(Scope scope, {String? alias}) → dynamic
findObservable(Scope? scope, String? key) → Observable?
findObservableInScope(Observable? target, String? scopeId, String? observableKey) → Observable?
hasScope(String? id) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
of(String? id) → Scope?
register(Observable observable) → dynamic
remove(Scope scope) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited