Platform class

Constructors

Platform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

backgroundColor Color?
no setter
isDesktop bool
no setter
isMobile bool
no setter
isWeb bool
no setter
operatingSystem String
no setter
operatingSystemVersion String
no setter
path Future<String?>
no setter
platform String
no setter
title String
no setter

Static Methods

createFolder(String folder) Future<String?>
deleteFile(String filepath) Future<bool>
fileExists(String filepath) bool
fileSaveAs(List<int> bytes, String filepath) Future
fileSaveAsFromBlob(dynamic blob, String filepath) → dynamic
fml2js({String? version}) → void
getFile(String? filepath) File?
getNavigationType() int
initialize() → dynamic
js2fml() → void
openPrinterDialog() → void
readFile(String? filepath) Future<String?>
readFileBytes(String? filepath) Future<Uint8List?>
writeFile(String? filepath, dynamic content) Future<bool>