PostMaster class

Constructors

PostMaster()
factory

Properties

alert ↔ bool
getter/setter pair
busy ↔ bool
getter/setter pair
errors ↔ int
getter/setter pair
frequency ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxattempts ↔ int
getter/setter pair
pending ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startNotified ↔ bool
getter/setter pair
timer ↔ Timer?
getter/setter pair

Methods

formPostable(String? key) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postable(Post post) → Future<bool>
start() → Future<bool>
stop() → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited