System class

Inheritance
Implemented types

Constructors

System()
factory

Properties

ancestors → List?
no setterinherited
busy ↔ bool
getter/setter pairinherited
busyObservable → BooleanObservable?
no setterinherited
children ↔ List<Model>?
getter/setter pairinherited
clock ↔ Timer?
getter/setter pair
connected → bool
no setter
context → BuildContext?
no setterinherited
currentLocation ↔ Payload?
getter/setter pair
data ↔ dynamic
getter/setter pairinherited
datasource ↔ String?
getter/setter pairinherited
datasources ↔ List<IDataSource>?
getter/setter pairinherited
debug ↔ bool
getter/setter pairinherited
descendants → List?
no setterinherited
element ↔ XmlElement?
getter/setter pairinherited
elementName → String
no setterinherited
framework ↔ FrameworkModel?
getter/setter pairinherited
gps ↔ Gps
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
latefinalinherited
isLocalScope ↔ bool
latefinalinherited
janitor → Janitor
final
manager → EventManager
Event Manager Host
final
mouse → bool
no setter
needsLayout ↔ bool
getter/setter pairinherited
operatingSystem → String?
no setter
operatingSystemVersion → String?
no setter
parent ↔ Model?
getter/setter pairinherited
postmaster → PostMaster
final
release → String
no setter
rootpath → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ Scope?
getter/setter pairinherited
screenheight ↔ int
getter/setter pair
screenwidth ↔ int
getter/setter pair
subscope → Scope?
no setterinherited
useragent → String?
no setter
userplatform → String?
no setter

Methods

broadcastEvent(Model source, Event event) → dynamic
override
day() → int
deserialize(XmlElement xml) → void
inherited
disableNotifications() → void
inherited
dispose() → void
disposes of the model releasing resources and removing bindings
inherited
enableNotifications() → void
inherited
epoch() → int
execute(String caller, String propertyOrFunction, List arguments) → Future<bool?>
inherited
executeEvent(Model source, String event) → dynamic
override
findAncestorOfExactType(Type T, {String? id, bool includeSiblings = false}) → dynamic
inherited
findAncestorsOfExactType(Type? T, {String? id, bool includeSiblings = false}) → List?
inherited
findChildOfExactType(Type T, {String? id}) → dynamic
inherited
findChildrenOfExactType(Type T, {String? id}) → List
inherited
findDescendantOfExactType(Type? T, {String? id}) → dynamic
inherited
findDescendantsOfExactType(Type? T, {String? id, Type? breakOn}) → List
inherited
findListenerOfExactType(Type T) → dynamic
inherited
findParentOfExactType(Type T, {String? id}) → dynamic
inherited
firstAncestorWhere(dynamic test(dynamic element)) → dynamic
inherited
getUniqueId(String? id) → String
inherited
hour() → int
initialize() → Future<void>
initializes the model by starting brokers
override
minute() → int
month() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners(String? property, dynamic value, {bool notify = false}) → dynamic
model listener notifications
inherited
onDataChange() → void
inherited
onDataSourceBusy(IDataSource source, bool busy) → dynamic
inherited
onDataSourceException(IDataSource source, Exception exception) → dynamic
inherited
onDataSourceSuccess(IDataSource source, Data? list) → Future<bool>
inherited
onMouseDetected() → dynamic
onPropertyChange(Observable observable) → void
notifies property listeners of any changes to a property
inherited
onShortcutHandler(KeyEvent event) → bool
registerEventListener(EventTypes type, OnEventCallback callback, {int? priority}) → dynamic
override
registerListener(IModelListener listener) → dynamic
adds a models listener to the list
inherited
removeAllListeners() → dynamic
removes all model listeners
inherited
removeChildrenOfExactType(Type T) → void
inherited
removeEventListener(EventTypes type, OnEventCallback callback) → dynamic
override
removeListener(IModelListener listener) → dynamic
removes a model listener from the list
inherited
second() → int
setActiveFramework(FrameworkModel model) → void
toString() → String
A string representation of this object.
inherited
year() → int

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

apps → List<ApplicationModel>
no setter
appsLoaded ↔ Completer<bool>
getter/setter pair
baseUrl ↔ String
getter/setter pair
companies → List<String>
final
currentApp ↔ ApplicationModel?
getter/setter pair
domain → String?
no setter
host → String?
no setter
initialized → Completer<bool>
final
scheme → String?
no setter
theme → ThemeModel
no setter
title → String
no setter

Static Methods

addApplication(ApplicationModel app) → Future<bool>
clearBranding() → void
deleteApplication(ApplicationModel app) → Future<bool>
launchApplication(ApplicationModel? app, {bool navigate = true}) → Future<void>
setApplicationTitle(String? title) → void
setBranding(String? icon) → void
toast(String? msg, {int? duration}) → dynamic

Constants

mainIcon → const String
changes the desktop icon
myId → const String