Template class

Constructors

Template({String? name, XmlDocument? document})
Template.clone({required Template template, Map<String, String?>? parameters})
factory
Template.error({required Template template, Map<String, String?>? parameters})
factory
Template.fromFml({String? name, required String fml, Map<String, String?>? parameters})
factory
Template.fromXmlDocument({String? name, XmlDocument? xml, Map<String, String?>? parameters})
factory

Properties

document → XmlDocument?
final
hashCode → int
The hash code for this object.
no setterinherited
isAutoGeneratedErrorPage → bool
no setter
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

errorPageAttribute ↔ String
getter/setter pair