FetchResult class

Constructors

FetchResult({dynamic code, String? message, String? detail, String? template, XmlDocument? document})

Properties

code ↔ int
latefinal
detail → String?
final
document ↔ XmlDocument?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon → String
no setter
isFail → bool
no setter
isSuccess → bool
no setter
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
template → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited