TemplateManager class

Constructors

TemplateManager()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templates ↔ HashMap<String, XmlDocument>
getter/setter pair

Methods

fetch({required String url, Map<String, String?>? parameters, required bool refresh}) → Future<Template>
fetchErrorTemplate(FetchResult result) → Future<Template>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMemory(String key, XmlDocument document) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited