WidgetAlignment class

Constructors

WidgetAlignment(LayoutType modelLayoutType, bool? center, String? halign, String? valign)

Properties

aligned ↔ Alignment
getter/setter pair
crossAlignment ↔ CrossAxisAlignment
getter/setter pair
crossWrapAlignment ↔ WrapCrossAlignment
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mainAlignment ↔ MainAxisAlignment
getter/setter pair
mainWrapAlignment ↔ WrapAlignment
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited