CameraViewState class

Inheritance

Constructors

CameraViewState()

Properties

backgroundStream ↔ StreamView?
getter/setter pair
cameras ↔ List<CameraDescription>?
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
controller ↔ CameraController?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initialized ↔ bool
getter/setter pair
model → ViewableMixin?
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
overlays ↔ List<OverlayEntry>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectorbutton ↔ IconView?
getter/setter pair
shutterbutton ↔ IconView?
getter/setter pair
widget → CameraView
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addMargins(Widget view) → Widget
applies margins to the view based on the widget model
inherited
applyConstraints(Widget view, Constraints constraints) → Widget
This routine applies the given constraints to the supplied view and then returns a widget with the view wrapped in those constraints
inherited
applyTransforms(Widget view) → Widget
applies transforms like rotate, flip, etc.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant dynamic oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLayout(BoxConstraints constraints) → void
inherited
onModelChange(Model model, {String? property, dynamic value}) → dynamic
Callback to fire the CameraViewState.build when the CameraModel changes
override
onSnapshot(XFile image) → Future<bool>
onStream(CameraImage image, CameraDescription camera) → void
onViewFinderTap(TapDownDetails details, BoxConstraints constraints) → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
reconfigureCameras() → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
snapshot() → Future<bool>
start() → Future<bool>
stop() → Future<bool>
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toggleCamera() → dynamic
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited