ViewState class

Inheritance

Constructors

ViewState()

Properties

abort bool
getter/setter pair
cameras List
getter/setter pair
canvas CanvasElement
getter/setter pair
canvas2 CanvasElement
getter/setter pair
context BuildContext
The location in the tree where this widget builds.
no setterinherited
detectedFrame num
getter/setter pair
detectInImage bool
getter/setter pair
detectionTimer Timer?
getter/setter pair
devices Map<String, String>
getter/setter pair
doneonce bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
lastFrame num
getter/setter pair
model ViewableMixin?
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedCamera int
getter/setter pair
stream MediaStream?
getter/setter pair
tolerance int
getter/setter pair
video VideoElement
getter/setter pair
videoWidget Widget?
getter/setter pair
widget View
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addMargins(Widget view) Widget
applies margins to the view based on the widget model
inherited
applyConstraints(Widget view, Constraints constraints) Widget
This routine applies the given constraints to the supplied view and then returns a widget with the view wrapped in those constraints
inherited
applyTransforms(Widget view) Widget
applies transforms like rotate, flip, etc.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
calculateSize(Map<String, int> srcSize, Map<String, int> dstSize) Map<String, dynamic>
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant dynamic oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(dynamic error) → dynamic
onLayout(BoxConstraints constraints) → void
inherited
onModelChange(Model model, {String? property, dynamic value}) → dynamic
Callback to fire the _ViewState.build when the CameraModel changes
override
onSnapshot(List<int> bytes, int width, int height, UriData uri) Future<void>
onStream(List<int> bytes, int width, int height) → void
pause() Future
performDetection() → void
play() Future
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
renderFrame(num epoch) → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
snapshot() Future
start() Future
stop() Future
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toggleCamera() → dynamic
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited