backDrawRodData property
BackgroundBarChartRodData
backDrawRodData
finalinherited
If you want to have a bar drawn in rear of this rod, use backDrawRodData,
it uses to have a bar with a passive color in rear of the rod,
for example you can use it as the maximum value place holder.
Implementation
final BackgroundBarChartRodData backDrawRodData;