gradient property
If provided, this BarChartRodData draws with this gradient.
Otherwise we use color to draw the background.
It throws an exception if you provide both color and gradient
Implementation
final Gradient? gradient;
If provided, this BarChartRodData draws with this gradient.
Otherwise we use color to draw the background.
It throws an exception if you provide both color and gradient
final Gradient? gradient;