FlSpotExtended class

Implemented types

Constructors

FlSpotExtended(ChartPainterSeriesModel series, dynamic data, double x, double y)
const

Properties

data → dynamic
final
hashCode int
Override hashCode
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
series ChartPainterSeriesModel
final
x double
finalinherited
y double
finalinherited

Methods

copyWith({double? x, double? y}) → FlSpot
Copies current FlSpot to a new FlSpot, and replaces provided values.
inherited
isNotNull() bool
Determines if x and y is not null.
inherited
isNull() bool
Determines if x or y is null.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Prints x and y coordinates of FlSpot list
inherited

Operators

operator ==(Object other) bool
Two FlSpot are equal if their x and y are equal.
inherited