PieChartSectionDataExtended class

Implemented types

Constructors

PieChartSectionDataExtended(ChartPainterSeriesModel series, dynamic data, {double? value, Color? color, double? radius, bool? showTitle, TextStyle? titleStyle, String? title, BorderSide? borderSide, Widget? badgeWidget, double? titlePositionPercentageOffset, double? badgePositionPercentageOffset})

Properties

badgePositionPercentageOffset → double
Defines position of badge widget in the section.
finalinherited
badgeWidget → Widget?
Defines a widget that represents the section.
finalinherited
borderSide → BorderSide
Defines border stroke around the section
finalinherited
color → Color
Defines the color of section.
finalinherited
data → dynamic
final
gradient → Gradient?
Defines the gradient of section. If specified, overrides the color setting.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
radius → double
Defines the radius of section.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series → ChartPainterSeriesModel
final
showTitle → bool
Defines show or hide the title of section.
finalinherited
title → String
Defines text of showing title at the middle of section.
finalinherited
titlePositionPercentageOffset → double
Defines position of showing title in the section.
finalinherited
titleStyle → TextStyle?
Defines style of showing title of section.
finalinherited
value → double
It determines how much space it should occupy around the circle.
finalinherited

Methods

copyWith({double? value, Color? color, Gradient? gradient, double? radius, bool? showTitle, TextStyle? titleStyle, String? title, BorderSide? borderSide, Widget? badgeWidget, double? titlePositionPercentageOffset, double? badgePositionPercentageOffset}) → PieChartSectionData
Copies current PieChartSectionData to a new PieChartSectionData, and replaces provided values.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited