value property
It determines how much space it should occupy around the circle.
This is depends on sum of all sections, each section should
occupy (value / sumValues) * 360 degrees.
value can not be null.
Implementation
final double value;
It determines how much space it should occupy around the circle.
This is depends on sum of all sections, each section should
occupy (value / sumValues) * 360 degrees.
value can not be null.
final double value;