DrawerViewState class

Inheritance
Implemented types

Constructors

DrawerViewState()

Properties

activeDrawer Drawers?
getter/setter pair
afterAnimation Function?
getter/setter pair
animate bool
getter/setter pair
animatingClose bool
getter/setter pair
bottom BoxView?
getter/setter pair
context BuildContext
The location in the tree where this widget builds.
no setterinherited
dragEdge double
getter/setter pair
fromBottom double?
getter/setter pair
fromLeft double?
getter/setter pair
fromRight double?
getter/setter pair
fromTop double?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
left BoxView?
getter/setter pair
model ViewableMixin?
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
oldHeight double?
getter/setter pair
oldWidth double?
getter/setter pair
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top BoxView?
getter/setter pair
visibleDrawer BoxView?
getter/setter pair
widget DrawerView
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addMargins(Widget view) Widget
applies margins to the view based on the widget model
inherited
applyConstraints(Widget view, Constraints constraints) Widget
This routine applies the given constraints to the supplied view and then returns a widget with the view wrapped in those constraints
inherited
applyTransforms(Widget view) Widget
applies transforms like rotate, flip, etc.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
builder(BuildContext context, BoxConstraints constraints) Widget
closeDrawer(Drawers? drawer, {dynamic cb}) → dynamic
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
override
didUpdateWidget(covariant DrawerView oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
finishedAnimation() → dynamic
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClose(Event event) → void
onDragEnd(DragEndDetails details, DragDirection direction, bool isOpen) → dynamic
override
onDragging(DragUpdateDetails details, DragDirection direction, bool isOpen) → dynamic
override
onDragStart(DragStartDetails dragStartDetails, DragDirection direction) → dynamic
override
onLayout(BoxConstraints constraints) → void
inherited
onModelChange(Model model, {String? property, dynamic value}) → dynamic
inherited
onOpen(Event event) → void
openBottom() → void
openDrawer(Drawers drawer) → dynamic
openLeft() → void
openRight() → void
openTop() → void
preventPop() → dynamic
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

dragLeeway int
getter/setter pair