IFormField class abstract

Implementers

Constructors

IFormField()

Properties

alarming → bool
no setter
answered → bool
no setter
defaultValue ↔ dynamic
getter/setter pair
dirty ↔ bool?
getter/setter pair
editable ↔ bool?
getter/setter pair
elementName → String
no setter
enabled ↔ bool
getter/setter pair
field ↔ String?
getter/setter pair
geocode ↔ Payload?
GeoCode for each IFormField which is set on answer
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setter
mandatory ↔ bool?
getter/setter pair
metaData ↔ dynamic
getter/setter pair
post ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
touched ↔ bool
getter/setter pair
value ↔ dynamic
getter/setter pair
values → List<String>?
no setter
visible → bool
no setter

Methods

answer(dynamic value) → Future<bool>
getActiveAlarm() → AlarmModel?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerDirtyListener(OnChangeCallback callback) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited