MenuViewState class
Methods
-
activate()
→ void
-
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
addMargins(Widget view)
→ Widget
-
applies margins to the view based on the widget model
inherited
-
applyConstraints(Widget view, Constraints constraints)
→ Widget
-
This routine applies the given constraints to the supplied
view and then returns a widget with the view wrapped in those
constraints
inherited
-
applyTransforms(Widget view)
→ Widget
-
applies transforms like rotate, flip, etc.
inherited
-
build(BuildContext context)
→ Widget
-
Describes the part of the user interface represented by this widget.
override
-
deactivate()
→ void
-
Called when this object is removed from the tree.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
didChangeDependencies()
→ void
-
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(covariant dynamic oldWidget)
→ void
-
Called whenever the widget configuration changes.
inherited
-
dispose()
→ void
-
Called when this object is removed from the tree permanently.
override
-
initState()
→ void
-
Called when this object is inserted into the tree.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onLayout(BoxConstraints constraints)
→ void
-
inherited
-
onModelChange(Model model, {String? property, dynamic value})
→ dynamic
-
inherited
-
positionOf()
→ Offset?
-
-
reassemble()
→ void
-
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
scroll(double? pixels, {required bool animate})
→ void
-
moves the scroller by the specified pixels in the specified direction
-
scrollTo(double? position, {bool animate = false})
→ dynamic
-
scrolls the widget with the specified context into view
-
scrollToContext(BuildContext context, {required bool animate})
→ dynamic
-
scrolls the widget with the specified context into view
-
setState(VoidCallback fn)
→ void
-
Notify the framework that the internal state of this object has changed.
inherited
-
sizeOf()
→ Size?
-
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringShort()
→ String
-
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited