IScrollable class abstract

Implementers

Constructors

IScrollable()

Properties

hashCode → int
The hash code for this object.
no setterinherited
moreDown ↔ bool
getter/setter pair
moreLeft ↔ bool
getter/setter pair
moreRight ↔ bool
getter/setter pair
moreUp ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

directionOf() → Axis
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionOf() → Offset?
scroll(double? pixels, {bool animate = true}) → void
scrollTo(String? id, String? value, {bool animate = true}) → void
sizeOf() → Size?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited