ShortcutHandler class

Constructors

ShortcutHandler()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

altKeys → List<String>
final
ctrlKeys → List<String>
final
defaultShortcuts → List<ShortcutModel>
final
isAltPressed → bool
no setter
isCtrlPressed → bool
no setter
isMetaPressed → bool
no setter
isShiftPressed → bool
no setter
keysPressed → List<LogicalKeyboardKey>
final
metaKeys → List<String>
final
shiftKeys → List<String>
final