TooltipViewState class

_ElTooltipState extends ElTooltip class

Inheritance
Implemented types
Mixed-in types

Constructors

TooltipViewState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
model ViewableMixin?
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
opener OpenMethods
getter/setter pair
overlayEntry OverlayEntry?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timer Timer?
getter/setter pair
view Widget
getter/setter pair
widget TooltipView
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addMargins(Widget view) Widget
applies margins to the view based on the widget model
inherited
applyConstraints(Widget view, Constraints constraints) Widget
This routine applies the given constraints to the supplied view and then returns a widget with the view wrapped in those constraints
inherited
applyTransforms(Widget view) Widget
applies transforms like rotate, flip, etc.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
canPop() Future<bool>
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeAccessibilityFeatures() → void
Called when the system changes the set of currently active accessibility features.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
override
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed. For example, if the user changes the system language settings.
inherited
didChangeMetrics() → void
Automatically hide the overlay when the screen dimension changes or when the user scrolls. This is done to avoid displacement.
override
didChangePlatformBrightness() → void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus(ViewFocusEvent event) → void
Called whenever the PlatformDispatcher receives a notification that the focus state on a view has changed.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPopRoute() Future<bool>
Called when the system tells the app to pop the current route, such as after a system back button press or back gesture.
inherited
didPushRoute(String route) Future<bool>
Called when the host tells the application to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit() Future<AppExitResponse>
Called when a request is received from the system to exit the application.
inherited
didUpdateWidget(covariant dynamic oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Dispose the observer
override
getNavigatorContext() BuildContext
override
handleCancelBackGesture() → void
Called when a predictive back gesture is canceled, indicating that no navigation should occur.
inherited
handleCommitBackGesture() → void
Called when a predictive back gesture is finished successfully, indicating that the current route should be popped.
inherited
handleStartBackGesture(PredictiveBackEvent backEvent) bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap() → void
Called when the user taps the status bar on iOS, to scroll a scroll view to the top.
inherited
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) → void
Called when a predictive back gesture moves.
inherited
hideOverlay() → void
Method to hide the tooltip
initState() → void
Init state and trigger the hidden overlay to measure its size
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLayout(BoxConstraints constraints) → void
inherited
onModelChange(Model model, {String? property, dynamic value}) → dynamic
inherited
onNavigatorChange() → void
override
onNavigatorPop() Map<String, String>?
override
onNavigatorPush({Map<String?, String>? parameters}) → void
override
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showOverlay(BuildContext context) → void
Loads the tooltip into view
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited