Model class

Implemented types
Implementers

Constructors

Model(Model? parent, String? id, {Scope? scope, dynamic data})

Properties

ancestors → List?
no setter
busy ↔ bool
getter/setter pair
busyObservable → BooleanObservable?
no setter
children ↔ List<Model>?
getter/setter pair
context → BuildContext?
no setter
data ↔ dynamic
getter/setter pair
datasource ↔ String?
getter/setter pair
datasources ↔ List<IDataSource>?
getter/setter pair
debug ↔ bool
getter/setter pair
descendants → List?
no setter
element ↔ XmlElement?
getter/setter pair
elementName → String
no setter
framework ↔ FrameworkModel?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
latefinal
isLocalScope ↔ bool
latefinal
needsLayout ↔ bool
getter/setter pair
parent ↔ Model?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ Scope?
getter/setter pair
subscope → Scope?
no setter

Methods

deserialize(XmlElement xml) → void
disableNotifications() → void
dispose() → void
disposes of the model releasing resources and removing bindings
enableNotifications() → void
execute(String caller, String propertyOrFunction, List arguments) → Future<bool?>
findAncestorOfExactType(Type T, {String? id, bool includeSiblings = false}) → dynamic
findAncestorsOfExactType(Type? T, {String? id, bool includeSiblings = false}) → List?
findChildOfExactType(Type T, {String? id}) → dynamic
findChildrenOfExactType(Type T, {String? id}) → List
findDescendantOfExactType(Type? T, {String? id}) → dynamic
findDescendantsOfExactType(Type? T, {String? id, Type? breakOn}) → List
findListenerOfExactType(Type T) → dynamic
findParentOfExactType(Type T, {String? id}) → dynamic
firstAncestorWhere(dynamic test(dynamic element)) → dynamic
getUniqueId(String? id) → String
initialize() → Future<void>
initializes the model by starting brokers
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners(String? property, dynamic value, {bool notify = false}) → dynamic
model listener notifications
onDataChange() → void
onDataSourceBusy(IDataSource source, bool busy) → dynamic
override
onDataSourceException(IDataSource source, Exception exception) → dynamic
override
onDataSourceSuccess(IDataSource source, Data? list) → Future<bool>
override
onPropertyChange(Observable observable) → void
notifies property listeners of any changes to a property
registerListener(IModelListener listener) → dynamic
adds a models listener to the list
removeAllListeners() → dynamic
removes all model listeners
removeChildrenOfExactType(Type T) → void
removeListener(IModelListener listener) → dynamic
removes a model listener from the list
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

onlyAlpha ↔ RegExp
getter/setter pair

Static Methods

fromXml(Model parent, XmlElement node, {Scope? scope, dynamic data}) → Model?
isBound(Model model, String? key) → bool
Returns true if the template references observable => key
set(Model model, String id, String propertyOrFunction, List arguments, Scope scope) → bool
unfocus() → dynamic