onPropertyChange method
notifies property listeners of any changes to a property
Implementation
void onPropertyChange(Observable observable) {
if(_notifications) {
notifyListeners(observable.key, observable.get());
}
}
notifies property listeners of any changes to a property
void onPropertyChange(Observable observable) {
if(_notifications) {
notifyListeners(observable.key, observable.get());
}
}