confirmExit property
String
get
confirmExit
Implementation
String get confirmExit {
if (language == french) {
return '(FR) Are you sure you want to exit the app?';
}
return 'Are you sure you want to exit the app?';
}