plotCategoryPoints method
void
plotCategoryPoints(
- dynamic dataList,
- List uniqueValues
)
Implementation
void plotCategoryPoints(dynamic dataList, List uniqueValues) {
xValues.clear();
lineDataPoint.clear();
int len = uniqueValues.length - 1;
for (var i = 0; i < dataList.length; i++) {
//set the data of the series for databinding
data = dataList[i];
if (uniqueValues.isNotEmpty && uniqueValues.contains(x)) {
x = uniqueValues.indexOf(x);
} else {
xValues.add(x);
x = len + 1;
len += 1;
}
//plot the point as a point object based on the desired function based on series and chart type.
plot(this, data);
}
dataList = null;
}