BarChartGroupDataExtended class
Properties
-
barRods
→ List<BarChartRodData>
-
BarChart renders barRods that represents a rod (or a bar) in the bar chart.
finalinherited
-
BarChart applies barsSpace between barRods if groupVertically is false.
finalinherited
-
data
→ dynamic
-
final
-
groupVertically
→ bool
-
If set true, it will show bars below/above each other.
Otherwise, it will show bars beside each other.
finalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
props
→ List<Object?>
-
Used for equality check, see
EquatableMixin.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
series
→ ChartPainterSeriesModel
-
final
-
showingTooltipIndicators
→ List<int>
-
you can show some tooltipIndicators (a popup with an information)
on top of each
BarChartRodData using showingTooltipIndicators,
just put indices you want to show it on top of them.
finalinherited
-
stringify
→ bool?
-
If set to
true, the toString method will be overridden to output
this instance's props.
no setterinherited
-
width
→ double
-
width of the group (sum of all
BarChartRodData's width and spaces)
no setterinherited
-
x
→ int
-
Order along the x axis in which titles, and titles only, will be shown.
finalinherited
Methods
-
copyWith({int? x, bool? groupVertically, List<BarChartRodData>? barRods, List<int>? showingTooltipIndicators})
→ BarChartGroupData
-
Copies current
BarChartGroupData to a new BarChartGroupData,
and replaces provided values.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited