BarChartRodDataExtended class
Constructors
-
BarChartRodDataExtended(ChartPainterSeriesModel series, dynamic data, {double? fromY, required double toY, Color? color, Gradient? gradient, double? width, BorderRadius? borderRadius, List<int>? borderDashArray, BorderSide? borderSide, BackgroundBarChartRodData? backDrawRodData, List<BarChartRodStackItem>? rodStackItems})
-
Properties
-
backDrawRodData
→ BackgroundBarChartRodData
-
If you want to have a bar drawn in rear of this rod, use
backDrawRodData,
it uses to have a bar with a passive color in rear of the rod,
for example you can use it as the maximum value place holder.
finalinherited
-
borderDashArray
→ List<int>?
-
If you want to have dashed border, set this value.
finalinherited
-
borderRadius
→ BorderRadius?
-
If you want to have a rounded rod, set this value.
finalinherited
-
borderSide
→ BorderSide
-
If you want to have a border for rod, set this value.
finalinherited
-
color
→ Color?
-
If provided, this
BarChartRodData draws with this color
Otherwise we use gradient to draw the background.
It throws an exception if you provide both color and gradient
finalinherited
-
data
→ dynamic
-
final
-
fromY
→ double
-
BarChart renders rods vertically from fromY.
finalinherited
-
gradient
→ Gradient?
-
If provided, this
BarChartRodData draws with this gradient.
Otherwise we use color to draw the background.
It throws an exception if you provide both color and gradient
finalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
props
→ List<Object?>
-
Used for equality check, see
EquatableMixin.
no setterinherited
-
rodStackItems
→ List<BarChartRodStackItem>
-
If you are a fan of stacked charts (If you don't know what is it, google it),
you can fill up the
rodStackItems to have a Stacked Chart.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
series
→ ChartPainterSeriesModel
-
final
-
stringify
→ bool?
-
If set to
true, the toString method will be overridden to output
this instance's props.
no setterinherited
-
toY
→ double
-
BarChart renders rods vertically from fromY to toY.
finalinherited
-
width
→ double
-
BarChart renders each rods with this value.
finalinherited
Methods
-
copyWith({double? fromY, double? toY, Color? color, Gradient? gradient, double? width, BorderRadius? borderRadius, List<int>? dashArray, BorderSide? borderSide, BackgroundBarChartRodData? backDrawRodData, List<BarChartRodStackItem>? rodStackItems})
→ BarChartRodData
-
Copies current
BarChartRodData to a new BarChartRodData,
and replaces provided values.
inherited
-
isUpward()
→ bool
-
Determines the upward or downward direction
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited