BarChartRodStackItemExtended class

Implemented types

Constructors

BarChartRodStackItemExtended(ChartPainterSeriesModel series, dynamic data, double fromY, double toY, Color color, [BorderSide border = const BorderSide(width: 0)])

Properties

borderSide BorderSide
Renders border stroke for a Stacked Chart section
finalinherited
color Color
Renders a Stacked Chart section with color
finalinherited
data → dynamic
final
fromY double
Renders a Stacked Chart section from fromY
finalinherited
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
Used for equality check, see EquatableMixin.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
series ChartPainterSeriesModel
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
toY double
Renders a Stacked Chart section to toY
finalinherited

Methods

copyWith({double? fromY, double? toY, Color? color, BorderSide? borderSide}) → BarChartRodStackItem
Copies current BarChartRodStackItem to a new BarChartRodStackItem, and replaces provided values.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited