FlSpotExtended class
- Implemented types
Constructors
- FlSpotExtended(ChartPainterSeriesModel series, dynamic data, double x, double y)
Properties
- data → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
Used for equality check, see
EquatableMixin.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- series → ChartPainterSeriesModel
-
final
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited - x → double
-
finalinherited
- y → double
-
finalinherited
Methods
-
copyWith(
{double? x, double? y}) → FlSpot -
Copies current
FlSpotto a newFlSpot, and replaces provided values.inherited -
isNotNull(
) → bool -
Determines if
xandyis not null.inherited -
isNull(
) → bool -
Determines if
xoryis null.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Prints x and y coordinates of FlSpot list
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited