ModalViewState class
- Inheritance
-
- Object
- State<
ModalView> - ViewableWidgetState<
ModalView> - ModalViewState
Constructors
Properties
- atMaxHeight ↔ bool
-
getter/setter pair
- atMaxWidth ↔ bool
-
getter/setter pair
- body ↔ Widget?
-
getter/setter pair
- closeHovered ↔ bool
-
getter/setter pair
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- dx ↔ double?
-
getter/setter pair
- dy ↔ double?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ double?
-
getter/setter pair
- lastDx ↔ double?
-
getter/setter pair
- lastDy ↔ double?
-
getter/setter pair
- lastHeight ↔ double?
-
getter/setter pair
- lastWidth ↔ double?
-
getter/setter pair
- maxHeight ↔ double
-
getter/setter pair
- maximized ↔ bool
-
getter/setter pair
- maximizedHovered ↔ bool
-
getter/setter pair
- maxWidth ↔ double
-
getter/setter pair
- minimized ↔ bool
-
getter/setter pair
- minimizeHovered ↔ bool
-
getter/setter pair
- model → ViewableMixin?
-
no setterinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- originalDx ↔ double?
-
getter/setter pair
- originalDy ↔ double?
-
getter/setter pair
- originalHeight ↔ double?
-
getter/setter pair
- originalWidth ↔ double?
-
getter/setter pair
- padding ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → ModalView
-
The current configuration.
no setterinherited
- width ↔ double?
-
getter/setter pair
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
addMargins(
Widget view) → Widget -
applies margins to the view based on the widget model
inherited
-
applyConstraints(
Widget view, Constraints constraints) → Widget -
This routine applies the given constraints to the supplied
view and then returns a widget with the view wrapped in those
constraints
inherited
-
applyTransforms(
Widget view) → Widget -
applies transforms like rotate, flip, etc.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant dynamic oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
inherited
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onBringToFront(
TapDownDetails? details) → dynamic -
onClose(
) → dynamic -
onCloseEvent(
Event event) → void -
onDismiss(
) → dynamic -
onDrag(
DragUpdateDetails details) → dynamic -
onDragEnd(
DragEndDetails details) → dynamic -
onLayout(
BoxConstraints constraints) → void -
inherited
-
onMaximize(
) → dynamic -
onMaximizeWindow(
) → dynamic -
onMeasured(
Size size, {dynamic data}) → dynamic -
onMinimize(
) → dynamic -
onModelChange(
Model model, {String? property, dynamic value}) → dynamic -
inherited
-
onResizeB(
DragUpdateDetails details) → dynamic -
onResizeBL(
DragUpdateDetails details) → dynamic -
onResizeBR(
DragUpdateDetails details) → dynamic -
onResizeL(
DragUpdateDetails details) → dynamic -
onResizeR(
DragUpdateDetails details) → dynamic -
onResizeT(
DragUpdateDetails details) → dynamic -
onResizeTL(
DragUpdateDetails details) → dynamic -
onResizeTR(
DragUpdateDetails details) → dynamic -
onRestore(
) → dynamic -
onRestoreTo(
) → dynamic -
onRestoreToLast(
) → dynamic -
onRestoreToOriginal(
) → dynamic -
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- headerIconDividerSize ↔ double
-
getter/setter pair
- headerIconSize ↔ double
-
getter/setter pair
- headerSize ↔ double
-
getter/setter pair
- minimumHeight ↔ double
-
getter/setter pair
- minimumWidth ↔ double
-
getter/setter pair