TableViewState class

Inheritance

Constructors

TableViewState()

Properties

busy Widget?
getter/setter pair
columns List<PlutoColumn>
final
context BuildContext
The location in the tree where this widget builds.
no setterinherited
currentRowIndex int?
no setter
grid ↔ PlutoGrid?
PlutoGridStateManager has many methods and properties to dynamically manipulate the grid. You can manipulate the grid dynamically at runtime by passing this through the onLoadedHandler callback.
getter/setter pair
groups List<PlutoColumnGroup>
final
hashCode int
The hash code for this object.
no setterinherited
map HashMap<PlutoColumn, TableHeaderCellModel>
final
model ViewableMixin?
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
mustBuildRowModel bool
getter/setter pair
paged bool
getter/setter pair
rows List<PlutoRow>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
themeHash int
getter/setter pair
views HashMap<TableRowCellModel, Widget>
final
widget TableView
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addMargins(Widget view) Widget
applies margins to the view based on the widget model
inherited
applyConstraints(Widget view, Constraints constraints) Widget
This routine applies the given constraints to the supplied view and then returns a widget with the view wrapped in those constraints
inherited
applyFilters(List<PlutoRow> list) List<PlutoRow>
applySort(List<PlutoRow> list) List<PlutoRow>
applyTransforms(Widget view) Widget
applies transforms like rotate, flip, etc.
inherited
autosize(String? mode) → void
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildAllRows() → void
buildOutRows(int length) → void
buildPlutoRow(int rowIdx) → PlutoRow?
buildRow(int rowIdx) → PlutoRow?
cellBuilder(PlutoColumnRendererContext context, bool hasEnterableFields) Widget
closeKeyboard() → dynamic
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
deleteRow(int? row) int?
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant dynamic oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
exportToCSV() Future<String?>
exportToPDF() Future<Uint8List?>
getColumnTitles(PlutoGridStateManager state) List<String>
getColumnType(TableHeaderCellModel model) → PlutoColumnType
getSerializedRow(PlutoGridStateManager state, PlutoRow plutoRow) List<String?>
getVisibleColumns(PlutoGridStateManager state) List<PlutoColumn>
initState() → void
Called when this object is inserted into the tree.
inherited
insertRow(int rowIndex) int?
isEditable(PlutoColumn col, PlutoRow row) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChangedHandler(PlutoGridOnChangedEvent event) → void
onDeselectHandler(PlutoGridOnRowDoubleTapEvent event) → void
onLayout(BoxConstraints constraints) → void
inherited
onLazyLoad(PlutoInfinityScrollRowsRequest request) Future<PlutoInfinityScrollRowsResponse>
onLoadedHandler(PlutoGridOnLoadedEvent event) → void
onModelChange(Model model, {String? property, dynamic value}) → dynamic
Callback function for when the model changes, used to force a rebuild with setState()
override
onPageLoad(PlutoLazyPaginationRequest request) Future<PlutoLazyPaginationResponse>
onRowsMoved(PlutoGridOnRowsMovedEvent event) → void
onSelectedHandler({bool force = false}) → void
onSortedHandler(PlutoGridOnSortedEvent event) → void
onTap(PlutoCell cell, int rowIdx) → dynamic
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
rebuild() → void
refresh() → void
reload() → void
setFilterBar(bool? on) → void
setPageSize(int size) → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited