grid property
PlutoGrid?
grid
getter/setter pair
PlutoGridStateManager has many methods and properties to dynamically manipulate the grid.
You can manipulate the grid dynamically at runtime by passing this through the onLoadedHandler callback.
Implementation
// pluto grid
PlutoGrid? grid;